@@ -95,8 +95,8 @@ def registration_callback(vreg):
         'TR? wf_info_for P, P patch_repository R, R title RT, U eid %(u)s, '
         'EXISTS(PS name "pending-review" AND P patch_reviewer U) '
         'OR EXISTS(PS name "reviewed" AND P patch_committer U) '
-        'OR (EXISTS(PS name IN ("reviewed", "deleted") AND NOT EXISTS(P patch_committer V) '
-        '    AND (EXISTS(R repository_committer U) OR EXISTS(U in_group G, G name "committers"))))'
+        'OR (EXISTS(PS name IN ("reviewed", "deleted") AND NOT EXISTS(P patch_committer U) '
+        '    AND (EXISTS(R repository_committer U) OR EXISTS(U in_group G, G name "committers")))), '
         'P patch_ticket T?, T done_in V?')
     vcreview_primary.RepositoryPatchesTable.rql = (
         'Any P,PO,P,PB,PS,COUNT(TR),T,V GROUPBY P,PO,PB,PS,T,V WHERE '
